pitchtools.insert_and_transpose_nested_subruns_in_chromatic_pitch_class_number_list
===================================================================================

.. autofunction:: abjad.tools.pitchtools.insert_and_transpose_nested_subruns_in_chromatic_pitch_class_number_list.insert_and_transpose_nested_subruns_in_chromatic_pitch_class_number_list
